
# This file is automatically generated by setup.py, So don't edit it. :)
VERSION_INFO = {
    'final': True,
    'version': '1.8.5',
    'branch_nick': '(no',
    'revision_id': '127a36fd53e5b4d9eb14ab02fe6c36443d78bfd0',
    'revno': 4502
}
